'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
function create() {
  var styleSheetElement = document.createElement('style');
  styleSheetElement.type = 'text/css';
  document.head.appendChild(styleSheetElement);

  var styleSheets = document.styleSheets;

  return {
    styleSheetElement: styleSheetElement,
    // Return the newly created stylesheet. We can assume it's the last.
    styleSheet: styleSheets[styleSheets.length - 1]
  };
}

function updateProperties(styleSheet, className, properties) {
  var existingRule = findExistingRule(styleSheet, className);

  if (existingRule) {
    Object.keys(properties).forEach(function (property) {
      existingRule.style[property] = properties[property];
    });
  } else {
    // https://developer.mozilla.org/en-US/docs/Web/API/CSSStyleSheet/insertRule
    // Insert an empty rule to the top so we can add rules to it.
    styleSheet.insertRule('.' + className + ' {}', 0);

    // The rule should exist now so try again.
    updateProperties(styleSheet, className, properties);
  }
}

function findExistingRule(styleSheet, className) {
  // http://stackoverflow.com/a/566445/228885
  var cssRuleCode = document.all ? 'rules' : 'cssRules'; // IE, FF
  var cssRules = styleSheet[cssRuleCode];
  var cssRule = void 0;
  var i = void 0;

  for (i = 0; i < cssRules.length; i++) {
    cssRule = cssRules[i];

    if (cssRule.selectorText === '.' + className) {
      return cssRule;
    }
  }

  return null;
}

exports.create = create;
exports.updateProperties = updateProperties;
exports.findExistingRule = findExistingRule;